Preface — cedar-backup3 3.10.0 documentation

# Preface

## Purpose

This software manual has been written to document version 2 and version 3 of Cedar Backup. Version 2 was first released in 2005, and version 3 in 2015.

## Audience

This manual has been written for computer-literate administrators who need to use and configure Cedar Backup on their Linux or UNIX-like system. The examples in this manual assume the reader is relatively comfortable with UNIX and command-line interfaces.

## Conventions Used in This Book

This section covers the various conventions used in this manual.

### Typographic Conventions

Term

  Used for first use of important terms.

`Command`

  Used for commands, command output, and switches

Replaceable

  Used for replaceable items in code and text

`Filenames`

  Used for file and directory names

### Icons

This icon designates a note relating to the surrounding text.

This icon designates a helpful tip relating to the surrounding text.

This icon designates a warning relating to the surrounding text.

## Organization of This Manual

Introduction

  Provides some some general history about Cedar Backup, what needs it is intended to meet, how to get support, and how to migrate from version 2 to version 3.

Basic Concepts:

  Discusses the basic concepts of a Cedar Backup infrastructure, and specifies terms used throughout the rest of the manual.

Installation

  Explains how to install Cedar Backup either from the Debian package or from the Python package.

Command Line Tools:

  Discusses the various Cedar Backup command-line tools, including the primary `cback3` command.

Configuration:

  Provides detailed information about how to configure Cedar Backup.

Official Extensions

  Describes each of the officially-supported Cedar Backup extensions.

Extension Architecture Interface

  Specifies the Cedar Backup extension architecture interface, through which third party developers can write extensions to Cedar Backup.

Dependencies

  Provides some additional information about the packages which Cedar Backup relies on, including information about how to find documentation and packages on non-Debian systems.

Data Recovery

  Cedar Backup provides no facility for restoring backups, assuming the administrator can handle this infrequent task. This appendix provides some notes for administrators to work from.

Securing Password-less SSH Connections

  Password-less SSH connections are a necessary evil when remote backup processes need to execute without human interaction. This appendix describes some ways that you can reduce the risk to your backup pool should your master machine be compromised.

Next: Introduction